==> qmmp-0.12.4.tar.bz2: qmmp-0.12.4/src/plugins/General/udisks/translations/udisks_plugin_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru">
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>UDisks Plugin Settings</source>
        <translation>Настройки модуля UDisks</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>CD Audio Detection</source>
        <translation>Автоопределение аудио-CD</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="38"/>
        <source>Add tracks to playlist automatically</source>
        <translation>Автоматически добавлять треки в список</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Remove tracks from playlist automatically</source>
        <translation>Автоматически удалять треки из списка</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Removable Device Detection</source>
        <translation>Автоопределение съёмных устройств</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="64"/>
        <source>Add files to playlist automatically</source>
        <translation>Автоматически добавлять треки в список</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="71"/>
        <source>Remove files from playlist automatically</source>
        <translation>Автоматически удалять треки из списка </translation>
    </message>
</context>
<context>
    <name>UDisksFactory</name>
    <message>
        <location filename="../udisksfactory.cpp" line="31"/>
        <source>UDisks Plugin</source>
        <translation>Модуль UDisks</translation>
    </message>
    <message>
        <location filename="../udisksfactory.cpp" line="51"/>
        <source>About UDisks Plugin</source>
        <translation>О модуле UDisks</translation>
    </message>
    <message>
        <location filename="../udisksfactory.cpp" line="52"/>
        <source>Qmmp UDisks Plugin</source>
        <translation>Модуль UDisks для Qmmp</translation>
    </message>
    <message>
        <location filename="../udisksfactory.cpp" line="53"/>
        <source>This plugin provides removable devices detection using UDisks</source>
        <translation>Этот модуль отслеживает съёмные устройства с помощью UDisks</translation>
    </message>
    <message>
        <location filename="../udisksfactory.cpp" line="54"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Разработчик: Илья Котов &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>UDisksPlugin</name>
    <message>
        <location filename="../udisksplugin.cpp" line="154"/>
        <source>Add CD &quot;%1&quot;</source>
        <translation>Добавить CD &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../udisksplugin.cpp" line="160"/>
        <source>Add Volume &quot;%1&quot;</source>
        <translation>Добавить том &quot;%1&quot;</translation>
    </message>
</context>
</TS>

==> qmmp_2.3.1.orig.tar.bz2: qmmp-2.3.1/src/plugins/General/udisks/translations/udisks_plugin_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>UDisksFactory</name>
    <message>
        <location filename="../udisksfactory.cpp" line="30"/>
        <source>UDisks Plugin</source>
        <translation>Модуль UDisks</translation>
    </message>
    <message>
        <location filename="../udisksfactory.cpp" line="50"/>
        <source>About UDisks Plugin</source>
        <translation>О модуле UDisks</translation>
    </message>
    <message>
        <location filename="../udisksfactory.cpp" line="51"/>
        <source>Qmmp UDisks Plugin</source>
        <translation>Модуль UDisks для Qmmp</translation>
    </message>
    <message>
        <location filename="../udisksfactory.cpp" line="52"/>
        <source>This plugin provides removable devices detection using UDisks</source>
        <translation>Этот модуль отслеживает съёмные устройства с помощью UDisks</translation>
    </message>
    <message>
        <location filename="../udisksfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Разработчик: Илья Котов &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>UDisksPlugin</name>
    <message>
        <location filename="../udisksplugin.cpp" line="132"/>
        <source>Add CD &quot;%1&quot;</source>
        <translation>Добавить CD &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../udisksplugin.cpp" line="140"/>
        <source>Add Volume &quot;%1&quot;</source>
        <translation>Добавить том &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>UDisksSettingsDialog</name>
    <message>
        <location filename="../udiskssettingsdialog.ui" line="14"/>
        <source>UDisks Plugin Settings</source>
        <translation>Настройки модуля UDisks</translation>
    </message>
    <message>
        <location filename="../udiskssettingsdialog.ui" line="29"/>
        <source>CD Audio Detection</source>
        <translation>Автоопределение аудио-CD</translation>
    </message>
    <message>
        <location filename="../udiskssettingsdialog.ui" line="38"/>
        <source>Add tracks to playlist automatically</source>
        <translation>Автоматически добавлять треки в список</translation>
    </message>
    <message>
        <location filename="../udiskssettingsdialog.ui" line="45"/>
        <source>Remove tracks from playlist automatically</source>
        <translation>Автоматически удалять треки из списка</translation>
    </message>
    <message>
        <location filename="../udiskssettingsdialog.ui" line="55"/>
        <source>Removable Device Detection</source>
        <translation>Автоопределение съёмных устройств</translation>
    </message>
    <message>
        <location filename="../udiskssettingsdialog.ui" line="64"/>
        <source>Add files to playlist automatically</source>
        <translation>Автоматически добавлять треки в список</translation>
    </message>
    <message>
        <location filename="../udiskssettingsdialog.ui" line="71"/>
        <source>Remove files from playlist automatically</source>
        <translation>Автоматически удалять треки из списка </translation>
    </message>
</context>
</TS>
